"use strict";
this.name = "ams_system";
this.author = "Thargoid";
this.copyright = "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description = "Needle-dart anti-missile system extension of the Missile Analyser, good for 6 uses before replacement.";
this.version = "2.12";

this.startUp = function () {
	if (missionVariables.amCount === undefined || missionVariables.amCount === null) {
		this.amCount = 6;
	} else {
		this.amCount = missionVariables.amCount;
	}
	if (missionVariables.amActive === undefined || missionVariables.amActive === null) {
		missionVariables.amActive = "INACTIVE";
	}
}

this.shipLaunchedFromStation = function () {
	if (player.ship.equipmentStatus("EQ_AMS") === "EQUIPMENT_OK" && player.ship.equipmentStatus("EQ_MISSILE_ANALYSER") === "EQUIPMENT_OK") {
		missionVariables.amActive = "ACTIVE";
		switch (this.amCount) {
			case 0:
				{
					player.consoleMessage("AMS - System offline, no darts loaded.", 5);
					break;
				}
			case 1:
				{
					player.consoleMessage("AMS - System online, 1 dart loaded.", 5);
					break;
				}
			default:
				{
					player.consoleMessage("AMS - System online, " + this.amCount + " darts loaded.", 5);
					break;
				}
		}
	}

}

this.$scanForMissiles = function () {
	function missileArray(entity) {
		return entity.isShip && entity.isMissile && entity.target && entity.target === player.ship;
	};
	let incomingMissiles = system.filteredEntities(this, missileArray, player.ship, 25600);
	if (incomingMissiles.length > 0) {
		this.shipAttackedWithMissile(incomingMissiles[0], null);
	}
}

this.shipAttackedWithMissile = function (missile, whom) {
	if (player.ship.equipmentStatus("EQ_AMS") === "EQUIPMENT_OK" && player.ship.equipmentStatus("EQ_MISSILE_ANALYSER") === "EQUIPMENT_OK" && missionVariables.amActive === "ACTIVE" && missile.name !== "Missile" && this.amCount > 0) {
		player.consoleMessage("AMS - Dart " + (7 - this.amCount) + " launched.", 6);
		let antiMissile = player.ship.spawnOne("ams_dart");
		antiMissile.target = missile;
		let amOrientation = player.ship.orientation;
		let offsetVector = amOrientation.vectorUp(); // vector at right angles to the player, downwards
		let spawnOffset = offsetVector.multiply(20); // set the offset to 20m downwards (for larger ships, increase 20).
		antiMissile.orientation = amOrientation; // point the dart in the same direction as the player
		antiMissile.position = player.ship.position.subtract(spawnOffset); // move the dart to it's correct start point.

		if (--this.amCount < 1) {
			player.consoleMessage("AMS - system exhausted, shutting down", 8);
		}
		missionVariables.amCount = this.amCount;
	}
}

this.playerBoughtEquipment = function (equipment) {
	switch (equipment) {
		case "EQ_AMS":
			{
				missionVariables.amActive = "ACTIVE";
				this.amCount = 6;
				break;
			}
		case "EQ_AMS_1":
			{
				this.amCount += 1;
				player.ship.removeEquipment("EQ_AMS_1");
				break;
			}
		case "EQ_AMS_2":
			{
				this.amCount += 2;
				player.ship.removeEquipment("EQ_AMS_2");
				break;
			}
		case "EQ_AMS_3":
			{
				this.amCount += 3;
				player.ship.removeEquipment("EQ_AMS_3");
				break;
			}
		case "EQ_AMS_4":
			{
				this.amCount += 4;
				player.ship.removeEquipment("EQ_AMS_4");
				break;
			}
		case "EQ_AMS_5":
			{
				this.amCount += 5;
				player.ship.removeEquipment("EQ_AMS_5");
				break;
			}
		case "EQ_AMS_6":
			{
				this.amCount += 6;
				player.ship.removeEquipment("EQ_AMS_6");
				break;
			}
		case "EQ_AMS_REMOVAL":
			{
				player.ship.removeEquipment("EQ_AMS");
				player.ship.removeEquipment("EQ_AMS_REMOVAL");
				player.credits += (5000 + (this.amCount * 400));
				this.amCount = 0;
				delete missionVariables.amCount;
				delete missionVariables.amActive;
				break;
			}
	}
	missionVariables.amCount = this.amCount;
}