"use strict";
this.name = "armoury_generalScript.js";
this.author = "Thargoid";
this.copyright = "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description = "Ship script for Armoury OXP";
this.version = "1.11";

// functions for various bombs supplied in the OXP

this.detonate = function () {
	if (!this.ship.owner.isValid) {
		this.ship.explode();
		return;
	}
	this.bomber = this.ship.owner;
	this.totalBounty = 0;
	this.energyAvailable = 64; // bombs own single energy bank.
	this.bomberEnergy = this.bomber.energy - 64; // max energy possible to put into EMP broadcast (leave bomber at least 1 energy bank)
	if (this.bomberEnergy > 0) {
		this.energyTransfer = 0.25 + (Math.random() * 0.75); // between 25% and 100% transfer of available energy
		this.energyDeduction = (this.bomberEnergy * this.energyTransfer); // how much energy we're going to transfer to the blast.
		this.bomber.energy -= this.energyDeduction; // drain the bomber's energy banks accordingly
		this.energyAvailable += this.energyDeduction; // add the bomber energy to the bomb's own energy bank
	}

	switch (this.ship.scriptInfo.bombType) // check which type of bomb has just gone off.
	{
		case "Bug bomb":
		case "Buzz bomb":
			{
				this.generalBomb();
				break;
			}
		case "Uni bomb":
		case "Stun bomb":
			{
				this.effectBomb();
				break;
			}
	}
}

this.tidyUp = function () {
	if (this.totalBounty > 0 && this.bomber.isPlayer) {
		player.consoleMessage("Total bomb bounty : " + this.totalBounty + " ₢.", 6);
		player.credits += this.totalBounty;
	}

	if (!this.bomber.isPlayer && player.ship && this.bomber && this.bomber.position.distanceTo(player.ship.position) < 25600) {
		player.consoleMessage(this.ship.scriptInfo.bombType + " detonation detected", 6);
	}
	this.ship.explode(); // get rid of the bomb entity
}

this.effectBomb = function () {
	function isPowered(entity) {
		return (entity.isShip && (this.ship.owner && entity != this.ship.owner) && (entity.isPlayer || (!entity.isMainStation && entity != this.bomber && entity.scanClass != "CLASS_CARGO" && entity.scanClass != "CLASS_ROCK"))); // ships who aren't cargo or rock.
	}

	var targetArray = system.filteredEntities(this, isPowered, this.ship, 25600);
	if (targetArray.length > 0) {
		var targetCounter = 0; // reset the counter
		for (targetCounter = 0; targetCounter < targetArray.length; targetCounter++) {
			this.distanceChance = 1 - ((this.ship.position.distanceTo(targetArray[targetCounter].position)) / 25600); // distance dependence
			this.energyChance = this.energyAvailable / targetArray[targetCounter].energy; // energy dependence
			if (Math.random() < (this.distanceChance * this.energyChance)) {
				switch (this.ship.scriptInfo.bombType) // check which type of bomb has just gone off.
				{
					case "Uni bomb":
						{
							if (this.bomber.isPlayer) {
								player.score += 1;
								this.totalBounty += targetArray[targetCounter].bounty;
								targetArray[targetCounter].explode();
							} else {
								if (targetArray[targetCounter].isPlayer) {
									this.newEnergy = 32 + (Math.random() * 32);
									if (player.ship.energy > this.newEnergy) {
										player.ship.energy = this.newEnergy; // rather than nuking the player, set their energy very low
									}
								} else {
									targetArray[targetCounter].explode();
								}
							}
							break;
						}

					case "Stun bomb":
						{
							if (targetArray[targetCounter].isPlayer) {
								player.ship.target = null;
								this.newOrient = new Quaternion;
								this.newOrient.w = (Math.random() * 2) - 1;
								this.newOrient.x = (Math.random() * 2) - 1;
								this.newOrient.y = (Math.random() * 2) - 1;
								this.newOrient.z = (Math.random() * 2) - 1;
								player.ship.orientation = this.newOrient; // as we can't stun the player, let's spin him about.
								player.consoleMessage("Flight control restored.", 6);
							} else {
								targetArray[targetCounter].setAI("armoury_stunnedAI.plist");
							}
							break;
						}
				}

			}
		}
	}
	this.tidyUp();
}


this.generalBomb = function () {
	function isPowered(entity) {
		return (entity.isShip && entity != this.bomber && entity.scanClass != "CLASS_CARGO" && entity.scanClass != "CLASS_ROCK");
	}

	this.damageWeight = 0.5; // damage weighting reduction adjustable for gameplay

	var targetArray = system.filteredEntities(this, isPowered, this.ship, 25600);

	if (targetArray.length > 0) {
		var targetCounter = 0; // reset the counter
		for (targetCounter = 0; targetCounter < targetArray.length; targetCounter++) {
			this.damageMultiplier = 1 - ((this.ship.position.distanceTo(targetArray[targetCounter].position)) / 25600); // distance dependence
			this.damage = (this.energyAvailable * this.damageMultiplier);
			if ((this.ship.scriptInfo.bombType) == "Bug bomb" && !targetArray[targetCounter].isThargoid) {
				this.damage *= this.damageWeight;
			}
			if ((this.ship.scriptInfo.bombType) == "Buzz bomb" && targetArray[targetCounter].isThargoid) {
				this.damage *= this.damageWeight;
			}

			if (this.damage > targetArray[targetCounter].energy) {
				if (this.bomber.isPlayer) {
					player.score += 1;
					this.totalBounty += targetArray[targetCounter].bounty;
				}
				targetArray[targetCounter].explode();
			} else {
				targetArray[targetCounter].energy -= this.damage;
			}
		}
	}
	this.tidyUp();
}