"use strict";
this.name = "armoury_interdictorMine.js";
this.author = "Thargoid";
this.copyright = "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description = "Ship script for the interdictor mine";
this.version = "1.13";

this.shipSpawned = function () {
	this.ship.desiredSpeed = 0;
	this.destructChance = -1;
	this.messageFlag = "OFF";
	this.autolockFlag = "NULL";

	if (worldScripts["targetAutolock"] && missionVariables.targetAutolock === "TRUE") {
		this.autolockFlag = "STOPPED";
		missionVariables.targetAutolock = null;
	}

	this.policeArray = system.entitiesWithScanClass("CLASS_POLICE", this.ship, 25600)
	if (this.policeArray.length > 0 && this.ship.owner && !this.ship.owner.isPolice) {
		this.ship.owner.bounty += 20;
		this.policeArray[0].reactToAIMessage("OFFENCE_COMMITTED");
	}

	this.interdictTimer = new Timer(this, this.performInterdict, 0, 0.5);
}

this.playerWillEnterWitchspace = this.shipDied = function () {
	if (this.interdictTimer && this.interdictTimer.isRunning) {
		this.interdictTimer.stop();
	}

	if (this.autolockFlag == "STOPPED") {
		this.autolockFlag = "NULL";
		missionVariables.targetAutolock = "TRUE";
	}
}

this.performInterdict = function () {
	if (!this.ship.isValid || !player.ship.isValid) {
		this.shipDied();
		return;
	}

	if (Math.random() < this.destructChance) // increasing chance that the mine's energy has run out and it self-destructs
	{
		this.ship.explode();
		this.shipDied();
		return;
	} else {
		this.destructChance += 0.01;
	}

	if (this.ship.position.distanceTo(player.ship.position) < 25600) {
		if (this.messageFlag == "OFF") {
			player.consoleMessage("Targetting system is being jammed by interdictor mine");
			this.messageFlag = "ON";
		}
	} else {
		this.messageFlag = "OFF";
		if (this.autolockFlag == "STOPPED") {
			this.autolockFlag = "NULL";
			missionVariables.targetAutolock = "TRUE";
		}
	}

	function isInterdictorTarget(entity) {
		return (entity.isShip && entity.target && !entity.isThargoid && !entity.isPolice);
	}

	var targetArray = system.filteredEntities(this, isInterdictorTarget, this.ship, 25600)
	if (targetArray.length > 0) {
		var targetCounter = 0;
		for (targetCounter = 0; targetCounter < targetArray.length; targetCounter++) {
			if (!targetArray[targetCounter].isPlayer) {
				targetArray[targetCounter].target = null;
			} else {
				player.ship.target = null;
				this.messageFlag = "ON";
			}
		}
	}
}